aboutsummaryrefslogtreecommitdiffstats
path: root/src/sccp_user.c
diff options
context:
space:
mode:
authorVadim Yanitskiy <vyanitskiy@sysmocom.de>2024-02-15 05:29:14 +0700
committerVadim Yanitskiy <vyanitskiy@sysmocom.de>2024-02-27 00:45:56 +0700
commit4d7e20193c264585080b9edc91eb630dd005e396 (patch)
treeeb70fa359de9153bb248745d5665c44e81496ceb /src/sccp_user.c
parent22929b1c04538e0f4ad53698874285bbc3395345 (diff)
VTY: rename 'sctp-role' to 'transport-role', add an alias
Now that we're adding support for M3UA-over-TCP, the transport layer role is no longer an SCTP specific paremeter, but rather a generic one. This is also the case for the OSMO_SS7_ASP_PROT_IPA, which employs TCP, and for which we can also choose between the client and server role. The 'sctp-role' now becomes an alias to 'transport-role', so that we keep backwards compatibility with old config files. Change-Id: Iab6c898181d79a5ed2bea767ee90e55bc3af16a5 Related: SYS#5424
Diffstat (limited to 'src/sccp_user.c')
-rw-r--r--src/sccp_user.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/sccp_user.c b/src/sccp_user.c
index b72b2a6..1dd3b30 100644
--- a/src/sccp_user.c
+++ b/src/sccp_user.c
@@ -636,7 +636,7 @@ osmo_sccp_simple_client_on_ss7_id(void *ctx, uint32_t ss7_id, const char *name,
if (!asp)
goto out_rt;
asp_created = true;
- /* Ensure that the ASP we use is set to sctp-role client. */
+ /* Ensure that the ASP we use is set to operate as a client. */
asp->cfg.is_server = false;
/* Ensure that the ASP we use is set to role ASP. */
asp->cfg.role = OSMO_SS7_ASP_ROLE_ASP;
@@ -655,7 +655,7 @@ osmo_sccp_simple_client_on_ss7_id(void *ctx, uint32_t ss7_id, const char *name,
/* Extra sanity checks if the ASP asp-clnt-* was pre-configured over VTY: */
if (!asp->simple_client_allocated) {
/* Forbid ASPs defined through VTY that are not entirely
* configured. "role" and "sctp-role" must be explicitly provided:
*/
if (!asp->cfg.role_set_by_vty) {
LOGP(DLSCCP, LOGL_ERROR,
@@ -663,9 +663,9 @@ osmo_sccp_simple_client_on_ss7_id(void *ctx, uint32_t ss7_id, const char *name,
name, asp->cfg.name);
goto out_asp;
}
- if (!asp->cfg.sctp_role_set_by_vty) {
+ if (!asp->cfg.trans_role_set_by_vty) {
LOGP(DLSCCP, LOGL_ERROR,
- "%s: ASP %s defined in VTY but 'sctp-role' was not set there, please set it.\n",
+ "%s: ASP %s defined in VTY but 'transport-role' was not set there, please set it.\n",
name, asp->cfg.name);
goto out_asp;
}
@@ -673,19 +673,19 @@ osmo_sccp_simple_client_on_ss7_id(void *ctx, uint32_t ss7_id, const char *name,
/* If ASP was configured through VTY it may be explicitly configured as
* SCTP server. It may be a bit confusing since this function is to create
* a "SCCP simple client", but this allows users of this API such as
* osmo-hnbgw to support SCTP-role server if properly configured through VTY.
*/
if (asp->cfg.is_server) {
struct osmo_xua_server *xs;
LOGP(DLSCCP, LOGL_NOTICE,
- "%s: Requesting an SCCP simple client on ASP %s configured with 'sctp-role server'\n",
+ "%s: Requesting an SCCP simple client on ASP %s configured with 'transport-role server'\n",
name, asp->cfg.name);
xs = osmo_ss7_xua_server_find2(ss7,
asp->cfg.trans_proto, prot,
asp->cfg.local.port);
if (!xs) {
LOGP(DLSCCP, LOGL_ERROR, "%s: Requesting an SCCP simple client on ASP %s configured "
- "with 'sctp-role server' but no matching xUA server was configured!\n",
+ "with 'transport-role server' but no matching xUA server was configured!\n",
name, asp->cfg.name);
goto out_asp;
}
@@ -655,7 +655,7 @@ osmo_sccp_simple_client_on_ss7_id(void *ctx, uint32_t ss7_id, const char *name,
if (!asp->simple_client_allocated) {
/* Forbid ASPs defined through VTY that are not entirely
- * configured. "role" and "sctp-role" must be explicitly provided:
+ * configured. "role" and "transport-role" must be explicitly provided:
*/
if (!asp->cfg.role_set_by_vty) {
@@ -673,19 +673,19 @@ osmo_sccp_simple_client_on_ss7_id(void *ctx, uint32_t ss7_id, const char *name,
* SCTP server. It may be a bit confusing since this function is to create
* a "SCCP simple client", but this allows users of this API such as
- * osmo-hnbgw to support SCTP-role server if properly configured through VTY.
+ * osmo-hnbgw to support transport-role server if properly configured through VTY.
*/
if (asp->cfg.is_server) {